### This code scrapes citation information from Google Scholar for data-provisioning publications

library(RSelenium)
library(rvest)
library(jsonlite)

#Set up selenium
# Download binaries, start driver, and get client object.
rd <- rsDriver(browser = "firefox", port = 4445L)

ffd <- rd$client
ffd$close()

#read data
refs <- read.csv("data/refs.csv")

#read completed data
fn <- list.files("data/papers", pattern=".json")
jsonl <- lapply(fn, function(f) as.data.frame(fromJSON(file.path("data/papers",f))))
done <- do.call(rbind, jsonl)
nrow(done)

refs <- refs[!refs$reference_no %in% done$reference_no,]
nrow(refs)

#basic search term
url <- "https://scholar.google.de/scholar?hl=en&as_sdt=0%2C5&q="


n=500

cite_res <- rep(NA, n)
bib_txt <- rep(NA, n)

ffd$open()

for(i in 1:n){
	
	
	search_term <-gsub(" ", "\\+", refs[i,]$primary_reference)
	
	
	ffd$navigate(paste0(url, search_term))
	
	
	#get page
	page <- read_html(ffd$getPageSource()[[1]])
	
	#check robot
	if(length(grep("robot|unusual traffic|sorry", as.character(page))) > 0) {
		readline(prompt="Press [enter] to continue")
		
		#get page
		page <- read_html(ffd$getPageSource()[[1]])
	}
	
	# check title
	titles <- page %>%  html_nodes(xpath = '//*[@class="gs_rt"]') %>% 
		html_nodes("a") %>% 
		html_text()
	
	#titles without any html
	if(is.na(titles[1]))  {
		titles <- page %>%  html_nodes(xpath = '//*[@class="gs_rt"]') %>% html_nodes("span") 
		nn <- grep("id=", titles)
		
		titles <- titles[nn] %>% html_text()
	}
	
	comp <- adist(refs$reftitle[i], titles)
	
	
	if(length(which(comp < 10)) > 0){
		
		# Extract number of citations
		cites <- page %>%  html_nodes(xpath = '//*[@class="gs_fl"]') %>% 
			html_nodes("a")
		
		ncites <- gsub("Cited by ", "", cites[grep("Cited by", cites)] %>% html_text())[which.min(comp)]
		
		cite_res[i] <- ifelse(length(ncites)==0, 0, ncites)
		
		# Extract bib
		webElem <- ffd$findElement(using = 'xpath','//*[@class="gs_or_cit gs_nph"]')
		webElem$clickElement()
		Sys.sleep(1)
		
		webElem <- ffd$findElement(using = 'xpath','//*[@class="gs_citi"]')
		Sys.sleep(1)
		webElem$clickElement()
		
		page <- read_html(ffd$getPageSource()[[1]]) %>% html_text()
		
		#check robot
		if(length(grep("robot|unusual traffic|sorry", as.character(page))) > 0) {
			readline(prompt="Press [enter] to continue")
			page <- read_html(ffd$getPageSource()[[1]]) %>% html_text()
			
		}
		
		bib_txt[i] <- page
		
	}
	cat("\r", i)
	Sys.sleep(sample(1:20, 1))
}



df <- cbind.data.frame(reference_no=refs$reference_no[1:n], ncites=cite_res, bibtxt = bib_txt)
ng <- grep("^http|Sorry", df$bibtxt) #if it caught google scholar's robot message
if (length(ng)>0) df <- df[-ng,]

jsonlite::write_json(df, file.path("data/papers", paste(format(Sys.time(), "%Y-%m-%d_%H-%M"), "-refs.json", sep = "")))

ffd$close()
