### This code uses the chronosphere package to access the latest archived version of the PBDB
### The PBDB are used to compile the list of data-provisioning publications

pbdb <- chronosphere::fetch("pbdb", datadir="data/chronodat")

download.file("https://paleobiodb.org/data1.2/occs/refs.csv?base_name=Life&interval=Cryogenian,Holocene", "data/refs.csv")

all_refs <- read.csv("data/refs.csv", encoding="UTF-8")
all_refs <- all_refs[!is.na(all_refs$reference_no),]
nrow(all_refs)

save(all_refs, file="data/refs.RData")


# Load and save -----------------------------------------------------------
refs <- unique(pbdb[, c("reference_no", "primary_reference")])
load("data/refs.RData")

missing <- refs[!refs$reference_no %in% all_refs$reference_no,]

missing_refs <- list()

for(i in 1:nrow(missing)){
	cat("\r", i, "out of", nrow(missing))
	url <- sprintf("https://paleobiodb.org/data1.1/refs/single.csv?id=%s&show=both", missing$reference_no[i])
	
	missing_refs[[i]] <- read.csv(url, encoding = "UTF-8")	
}

#remove not found
missing_refs <- missing_refs[unlist(lapply(missing_refs, nrow)) == 1]

missing_refs <- do.call(rbind, missing_refs)

all_refs <- data.table::rbindlist(list(all_refs, missing_refs), fill=T)
missing <- refs[!refs$reference_no %in% all_refs$reference_no,]
write.csv(missing, "data/missing.csv", row.names=F)

missing_occ <- subset(pbdb, reference_no %in% missing$reference_no)
write.csv(missing_occ, "data/missing_occ.csv", row.names=F)

refs <- merge(refs, all_refs, all.x=T, all.y=F)
refs <- refs[!refs$publication_type %in% c("unpublished", "compendium"),]
nrow(refs)

write.csv(refs, "data/refs.csv", row.names=F)

