################################################################################
# Script template to do the manual processing of the supplementary data items.
# Ádám T. Kocsis
# 2021-08-01 Erlangen

# Laura Mulvey

########################################----------------------------------------
# 1. Set-up
########################################----------------------------------------

# the official publication number
no <- 103 # for example - replace for each publication with data

# inform user
message(paste0("Processing PBDB official ref. ", no, "."))

# all offiical publication numbers
allNo <- unlist(lapply(strsplit(todo, "_"), function(x)x[1]))

# list out the files that are related
files <- todo[allNo==no]
(files)

# aggregation item for this official contribution
thisRef <- list()

########################################----------------------------------------
# 2. Processing of files
# A deliberate choice was made to hard-code the names.

# 0. Extraction containers
	fromRef <- NULL
	fromOcc <- NULL
	fromColl <- NULL

####################------------------------------------------------------------
# One file at a time
file <-"103_Kroger et al. 2009. pone.0007262.s001.xls" # for example
path <- file.path(dataFolder, file)

# A. LOAD
	# CSV template
	dat <-read.csv(path)

	# delim template
	dat <- read.delim(path)

	# rds template
	dat <- readRDS(path)

	# RData
	rdat <- new.env()
	load(path, envir=rdat)
	ls(rdat)

	# iterate on objects
	dat <- rdat[["berr_barr_moll_raw"]]

	# xlsx 
	dat <- readWorksheetFromFile(path, sheet=1, startRow=2)

# B. Extraction
# B1. Reference number
	oneRef <- unique(dat[, "reference_no"])
	oneRef <- oneRef[!is.na(oneRef)]
	fromRef <- unique(c(fromRef, oneRef))

# B2. Occurrence number


	occNo <- dat[,"occurrence_no"]

	# references of these collections from PBDB
	fromOcc <- unique(all[all$occurrence_no%in%occNo, "reference_no"])


# B3. Collection number
	collNo <- dat[,"Coll"]

	# omit missing
	collNo <- collNo[!is.na(collNo)]

	# references of these collections from PBDB
	fromColl <- unique(all[all$collection_no%in%collNo, "reference_no"])

# C. Aggregation
	thisRef <-list(fromRef, fromOcc, fromColl)
	names(thisRef) <- c("fromRef", "fromOcc", "fromColl")

####################------------------------------------------------------------
# Are some the files unprocessed?
# unprocessed <- c(unprocessed, files)

########################################----------------------------------------
# Export and cleanup
refs <- c(refs, list(thisRef))
names(refs)[length(refs)] <- no

# Remove the processed files from the list
todo <- todo[!todo%in%files]

